From: Karol Kolacinski <karol.kolacin...@intel.com>

Refactor the code by changing ice_ptp_init_phc_eth56g function
name to ice_ptp_init_phc_e825, to be consistent with the naming pattern
for other devices.

Signed-off-by: Karol Kolacinski <karol.kolacin...@intel.com>
Signed-off-by: Grzegorz Nitka <grzegorz.ni...@intel.com>
---
 drivers/net/ethernet/intel/ice/ice_ptp_hw.c | 13 ++++++-------
 1 file changed, 6 insertions(+), 7 deletions(-)

diff --git a/drivers/net/ethernet/intel/ice/ice_ptp_hw.c 
b/drivers/net/ethernet/intel/ice/ice_ptp_hw.c
index 3e824f7b30c0..fbaf2819e40e 100644
--- a/drivers/net/ethernet/intel/ice/ice_ptp_hw.c
+++ b/drivers/net/ethernet/intel/ice/ice_ptp_hw.c
@@ -2650,18 +2650,17 @@ static void ice_sb_access_ena_eth56g(struct ice_hw *hw, 
bool enable)
 }
 
 /**
  * ice_ptp_init_phc_eth56g - Perform E82X specific PHC initialization
  * @hw: pointer to HW struct
  *
  * Perform PHC initialization steps specific to E82X devices.
  *
- * Return:
- * * %0     - success
- * * %other - failed to initialize CGU
+ * Return: 0 on success, negative error code otherwise.
  */
-static int ice_ptp_init_phc_eth56g(struct ice_hw *hw)
+static int ice_ptp_init_phc_e825(struct ice_hw *hw)
 {
        ice_sb_access_ena_eth56g(hw, true);
+
        /* Initialize the Clock Generation Unit */
        return ice_init_cgu_e82x(hw);
 }
@@ -6123,7 +6122,7 @@ int ice_ptp_init_phc(struct ice_hw *hw)
        case ICE_MAC_GENERIC:
                return ice_ptp_init_phc_e82x(hw);
        case ICE_MAC_GENERIC_3K_E825:
-               return ice_ptp_init_phc_eth56g(hw);
+               return ice_ptp_init_phc_e825(hw);
        default:
                return -EOPNOTSUPP;
        }
@@ -2650,18 +2650,17 @@ static void ice_sb_access_ena_eth56g(struct ice_hw *hw, 
 
 /**
- * ice_ptp_init_phc_eth56g - Perform E82X specific PHC initialization
+ * ice_ptp_init_phc_e825 - Perform E825 specific PHC initialization
  * @hw: pointer to HW struct
  *
@@ -2650,18 +2650,17 @@ static void ice_sb_access_ena_eth56g(struct ice_hw *hw, 
  * @hw: pointer to HW struct
  *
- * Perform PHC initialization steps specific to E82X devices.
+ * Perform E825-specific PTP hardware clock initialization steps.
  *
-- 
2.39.3

Reply via email to